/**
 * Dayona
 * Created on Thu May 26 2022
 * email : dayonaart@gmail.com
 * Copyright (c) 2022
 */


import Flutter
import UIKit

public class SwiftDevicePropertiesPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "new_device_info", binaryMessenger: registrar.messenger())
    let instance = SwiftDevicePropertiesPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
      if(call.method == "getProperties"){
                    let modelName = UIDevice.modelName
          let ipAddress = self.getPublicIPAddress()
                    let systemVersion = UIDevice.current.systemVersion
                    let deviceData = """
                    {
                        "device_type": "\(String(modelName))",
                        "ip_address": "\(ipAddress.description)",
                        "os_version":"\(systemVersion)",
                        "app_version_code":"\(Bundle.main.releaseVersionNumber ?? "release_version")",
                        "app_build_code":"\(Bundle.main.buildVersionNumber ?? "app_version_code")"
                    }
                    """
                    result(deviceData)
                }else if(call.method == "getPublicIp"){
                    let ipAddress = self.getPublicIPAddress()
                    result(ipAddress.description)
                } else {
                    result(FlutterMethodNotImplemented)
                    return
                  }
  }
    private func getPublicIPAddress()->String {
          var publicIP = ""
          do {
              try publicIP = String(contentsOf: URL(string: "https://www.bluewindsolution.com/tools/getpublicip.php")!, encoding: String.Encoding.utf8)
              publicIP = publicIP.trimmingCharacters(in: CharacterSet.whitespaces)
          }
          catch {
            return  "Error: \(error)"

          }
        return publicIP
      }

}

extension Bundle {
  var releaseVersionNumber: String? {
      return infoDictionary?["CFBundleShortVersionString"] as? String
  }
  var buildVersionNumber: String? {
      return infoDictionary?["CFBundleVersion"] as? String
  }
}
