/*
 * Dayona
 * Created on Thu May 26 2022
 * email : dayonaart@gmail.com
 * Copyright (c) 2022
 */

import 'dart:convert';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'new_device_info_platform_interface.dart';

/// An implementation of [NewDeviceInfoPlatform] that uses method channels.
class MethodChannelNewDeviceInfo extends NewDeviceInfoPlatform {
  @visibleForTesting
  final methodChannel = const MethodChannel('new_device_info');

  @override
  Future<DevicesInfoModel?> getProperties() async {
    try {
      final version = await methodChannel.invokeMethod<String>('getProperties');
      return DevicesInfoModel.fromJson(jsonDecode(version!));
    } catch (e) {
      return null;
    }
  }

  @override
  Future<String?> getPublicIp() async {
    try {
      final publicIp = await methodChannel.invokeMethod<String>('getPublicIp');
      return publicIp;
    } catch (e) {
      return "cannnot get public ip";
    }
  }
}

class DevicesInfoModel {
  String? ipAddress;
  String? deviceType;
  String? osVersion;
  String? appVersionCode;
  String? buildVersionCode;
  DevicesInfoModel({
    this.ipAddress,
    this.deviceType,
    this.osVersion,
    this.appVersionCode,
    this.buildVersionCode,
  });

  factory DevicesInfoModel.fromJson(Map<String, dynamic> json) {
    return DevicesInfoModel(
        ipAddress: json['ip_address'] as String?,
        deviceType: json['device_type'] as String?,
        osVersion: json['os_version'] as String?,
        appVersionCode: json['app_version_code'] as String?,
        buildVersionCode: json['app_build_code'] as String?);
  }

  Map<String, dynamic> toJson() => {
        'ip_address': ipAddress,
        'device_type': deviceType,
        'os_version': osVersion,
        'app_version_code': appVersionCode,
        'app_build_code': buildVersionCode
      };
}
